# Introduction

Environment

- linux : ubuntu18.04
- GPU : Cupy CUDA
- python3.8

Calculating package for channel1000 and Channel5200(JHTDB)

- calculate gradient  (4,6,8-centered finite difference)

- dissipation

- basic statistics

# CONTACT

lxjproductivity@outlook.com

View at:
https://pypi.org/project/Turbulence/1.0.0/